from models.db import db_conn
from models.model import Model
import models.proteins
import models.experiments


class CondensateModel(Model):
    def __init__(self):
        self.collection_name = "condensates"
        self.allowed_params = {
            'query': str,
            'proteins': str,
            'species_tax_id': str,
            'page': int,
            'size': int,
        }
        self.unique_key = "unique_name"
        self.attributes = [
            'name',
            'unique_name',
            'species_tax_id',
            'species_name',
            'proteins',
            'data_sources'
        ]
        self.list_attributes = {
            'name': True,
            'unique_name': True,
            'species_tax_id': True,
            'species_name': True,
            'proteins': True,
            'data_sources': True
        }

    def fetch_record(self, unique_id):
        """
        Overriding base function for fetch record.
        Add custom and foreign key fields like "proteins"

        :param(str) unique_id: Unique ID of the condensate
        :return(dict):
        """
        record = self.serialize_record(db_conn[self.collection_name].find_one({self.unique_key: unique_id}))
        if not record:
            return
        if not record.get('proteins'):
            return record
        record['proteins'] = models.proteins.ProteinModel().fetch_by_unique_keys(record.get('proteins'))
        _, record['experiments'] = models.experiments.ExperimentModel().fetch_all(condensate_id=record.get('unique_name'))

        return record

