from models.db import db_conn


def get_all_proteins():
    proteins_coll = db_conn['proteins']
    aggregate_query = [
        {
            '$group': {
                '_id': "$species_name",
                'total': {'$sum': 1}
            }
        },
        {
            '$sort': {'total': -1}
        }
    ]
    response = proteins_coll.aggregate(aggregate_query)
    return list(response)


def get_all_condensates():
    condensates_coll = db_conn['condensates']
    aggregate_query = [
        {
            '$project': {
                '_id': 1,
                'species_name': {'$ifNull': ["$species_name", "Chimeras"]}
            }
        },
        {
            '$group': {
                '_id': "$species_name",
                'total': {'$sum': 1}
            }
        },
        {
            '$sort': {'total': -1}
        }
    ]
    response = condensates_coll.aggregate(aggregate_query)
    return list(response)


def get_protein_histogram():
    proteins_coll = db_conn['proteins']
    aggregate_query = [
        {
            '$lookup': {
                'from': 'condensates',
                'localField': 'uniprot_id',
                'foreignField': 'proteins',
                'as': 'condensates'
            }
        },
        {
            '$match': {
                'uniprot_id': {
                    '$exists': True,
                    '$ne': None
                }
            }
        },
        {
            '$project': {
                'uniprot_id': 1,
                'size': {
                    '$cond': {
                        'if': {'$isArray': '$condensates'},
                        'then': {'$size': '$condensates'},
                        'else': 0
                    }
                }
            }
        },
        {
            '$group': {
                '_id': '$size',
                'uniprot_id': {'$push': '$uniprot_id'},
                'total': {'$sum': 1}
            }
        },
        {
            '$sort': {'_id': 1}
        }
    ]
    response = proteins_coll.aggregate(aggregate_query)
    return list(response)


def get_condensates_histogram():
    condensates_coll = db_conn['condensates']
    aggregate_query = [
        {
            '$project': {
                'unique_name': 1,
                'size': {
                    '$cond': {
                        'if': {'$isArray': '$proteins'},
                        'then': {'$size': '$proteins'},
                        'else': 0
                    }
                }
            }
        },
        {
            '$group': {
                '_id': '$size',
                'condensate': {'$push': '$unique_name'},
                'total': {'$sum': 1}
            }
        },
        {
            '$sort': {'_id': 1}
        }
    ]
    response = condensates_coll.aggregate(aggregate_query)
    return list(response)


def get_experiments_per_condensate():
    experiments_coll = db_conn['experiments']
    aggregate_query = [
        {
            '$group': {
                '_id': '$condensate_id',
                'total': {'$sum': 1}
            }
        },
        {
            '$sort': {'total': -1}
        }
    ]
    response = experiments_coll.aggregate(aggregate_query)
    return list(response)


def get_condensates_per_evidence_list():
    condensates_coll = db_conn['condensates']
    aggregate_query = [
        {
            '$project': {
                'id': '$unique_name',
                'ds': '$data_sources'
            }
        },
        {
            '$unwind': '$ds'
        },
        {
            '$unwind': '$ds'
        },
        {
            '$group': {
                '_id': '$id',
                'res': {
                    '$addToSet': '$ds'
                }
            }
        },
        {
            '$unwind': '$res'
        },
        {
            '$sort': {'res': 1}
        },
        {
            '$group': {
                '_id': '$_id',
                'res': {
                    '$push': '$res'
                }
            }
        },
        {
            '$group': {
                '_id': '$res',
                'total': {
                    '$sum': 1
                }
            }
        },
        {
            '$sort': {'total': -1}
        }
    ]
    response = condensates_coll.aggregate(aggregate_query)
    return list(response)


def get_condensates_per_evidence():
    condensates_coll = db_conn['condensates']
    aggregate_query = [
        {
            '$project': {
                'id': '$unique_name',
                'ds': '$data_sources'
            }
        },
        {
            '$unwind': '$ds'
        },
        {
            '$unwind': '$ds'
        },
        {
            '$group': {
                '_id': '$ds',
                'total': {
                    '$sum': 1
                }
            }
        },
        {
            '$sort': {'total': -1}
        }
    ]
    response = condensates_coll.aggregate(aggregate_query)
    return list(response)

