const namespaced = true

const state = {
  cutoff: 0.005,
  pvalueCutoff: 0.001,
  proteinList: [],
  assays: ['appl'],
  marker: 'All',
  parameter: 'All'
}

const mutations = {
  SET_CUT_OFF (state, cutoff) {
    state.cutoff = cutoff
  },
  SET_P_VALUE_CUT_OFF (state, pvalue) {
    state.pvalueCutoff = pvalue
  },
  SET_PROTEIN_LIST (state, proteinList) {
    state.proteinList = proteinList
  },
  ADD_PROTEIN (state, protein) {
    if(state.proteinList.findIndex(d => d.proteinId === protein.proteinId) <0) {
      state.proteinList.push(protein)
    }
  },
  REMOVE_PROTEIN (state, proteinIdx) {
    state.proteinList.splice(proteinIdx, 1);
  },
}

const getters = {
  cutoff: state => state.cutoff,
  pvalueCutoff: state => state.pvalueCutoff,
  proteinList: state => state.proteinList,
}

const actions = {
  setCutOff ({ commit }, cutoff) {
    commit('SET_CUT_OFF', cutoff)
  },
  setPValueCutOff ({ commit }, pvalue) {
    commit('SET_P_VALUE_CUT_OFF', pvalue)
  },
  setProteinList ({ commit }, proteinList) {
    commit('SET_PROTEIN_LIST', proteinList)
  },
  addProtein ({ commit }, protein) {
    commit('ADD_PROTEIN', protein)
  },
  removeProtein ({ commit }, protein) {
    commit('REMOVE_PROTEIN', protein)
  }
}

export default {
  namespaced,
  state,
  mutations,
  getters,
  actions
}
